package com.softbankrobotics.pepperhelloworld;

import android.graphics.Color;
import android.support.constraint.ConstraintLayout;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import com.aldebaran.qi.sdk.QiContext;
import com.aldebaran.qi.sdk.QiSDK;
import com.aldebaran.qi.sdk.RobotLifecycleCallbacks;
import com.aldebaran.qi.sdk.builder.ChatBuilder;
import com.aldebaran.qi.sdk.builder.QiChatbotBuilder;
import com.aldebaran.qi.sdk.builder.SayBuilder;
import com.aldebaran.qi.sdk.builder.TopicBuilder;
import com.aldebaran.qi.sdk.design.activity.RobotActivity;
import com.aldebaran.qi.sdk.object.conversation.Bookmark;
import com.aldebaran.qi.sdk.object.conversation.Chat;
import com.aldebaran.qi.sdk.object.conversation.QiChatbot;
import com.aldebaran.qi.sdk.object.conversation.Say;
import com.aldebaran.qi.sdk.object.conversation.Topic;

public class MainActivity extends RobotActivity implements RobotLifecycleCallbacks {

    private QiChatbot qiChatbot;
    private ConstraintLayout mainFrame;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mainFrame = findViewById(R.id.mainFrame);

        QiSDK.register(this,this);
    }

    @Override
    protected void onDestroy() {

        QiSDK.unregister(this,this);

        super.onDestroy();
    }

    @Override
    public void onRobotFocusGained(QiContext qiContext) {
        Log.i("MyTag", "onRobotFocusGained");

        /*Say say = SayBuilder.with(qiContext)
                .withText("こんにちは　ペッパーです")
                .build();

        say.run();*/

        Topic sayHelloTopic = TopicBuilder.with(qiContext)
                .withResource(R.raw.hello_topic)
                .build();

        Topic updateColorTopic = TopicBuilder.with(qiContext)
                .withResource(R.raw.update_color)
                .build();

        qiChatbot = QiChatbotBuilder.with(qiContext)
                .withTopic(sayHelloTopic, updateColorTopic)
                .build();

        qiChatbot.addOnBookmarkReachedListener(new QiChatbot.OnBookmarkReachedListener() {
            @Override
            public void onBookmarkReached(Bookmark bookmark) {
                if("show_favorite_color".equals(bookmark.getName())){
                    updateTabletColor();
                }
            }
        });

        Chat chat = ChatBuilder.with(qiContext)
                .withChatbot(qiChatbot)
                .build();

        chat.async().run();

    }

    private void updateTabletColor() {
        if(qiChatbot == null){
            return;
        }
        String tabletColor = qiChatbot.variable(("favorite_color")).getValue();
        final int androidTabletColor = getAndroidTabletColor(tabletColor);

        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                mainFrame.setBackgroundColor(androidTabletColor);
            }
        });
    }

    private int getAndroidTabletColor(String color) {
        switch (color){
            case "赤":
                return Color.RED;
            case "青":
                return Color.BLUE;
            case "緑":
                return Color.GREEN;
            default:
                return 0;
        }
    }


    @Override
    public void onRobotFocusLost() {

    }

    @Override
    public void onRobotFocusRefused(String reason) {

    }
}
